# Contributing

👍🎉 First off, thank you for taking the time to contribute! 🎉👍

Check out the [online docs](https://docs.lmcache.ai/developer_guide/contributing.html) for a set of guidelines for contributing. 